import logging
import os
from cryptography.fernet import Fernet

from torrent_ds.error import EncryptException
from torrent_ds.config import load_credentials, get_key_path

class Credential:
    def __init__(self, name):
        self._name = name
        self._key_path = get_key_path()
        self._key = None
        self._logger = logging.getLogger("torrent-ds")
        self._credential_path, self._config = load_credentials()

        self._check_key()
        if not self._is_encrypted:
            self._encrypt()
        self._username = self._config[self._name]["user_name"]
        self._password = self._config[self._name]["password"]

    def _check_key(self):
        if not self._key_exists and self._is_encrypted:
            msg = "The key file: '{}' does not exists, to decrypt password.".format(self._key_path)
            self._logger.error(msg)
            raise EncryptException(msg)

        if not self._key_exists:
            self._create_key()
        else:
            self._read_key()

    def _create_key(self):
        self._key = Fernet.generate_key()
        with open(self._key_path, 'w') as f:
            f.write(self._key.decode())

    def _read_key(self):
        with open(self._key_path, 'r') as f:
            self._key = f.read().encode()

    def _decrypt(self):
        f = Fernet(self._key)
        return f.decrypt(self._password.encode()).decode()

    def _encrypt(self):
        f = Fernet(self._key)
        self._config[self._name]["password"] = f.encrypt(self._config[self._name]["raw_password"].encode()).decode()
        self._config[self._name]["raw_password"] = ""
        self._write_creds()

    def _write_creds(self):
        with open(self._credential_path, "w") as f:
            self._config.write(f)

    @property
    def _is_encrypted(self):
        if len(self._config[self._name]["raw_password"]) > 0:
            return False
        else:
            if len(self._config[self._name]["password"]) > 0:
                return True
            else:
                msg = "Missing password or raw password field in credential: '{}' for '{}'.".format(self._credential_path, self._name)
                self._logger.error(msg)
                raise EncryptException(msg)

    @property
    def _key_exists(self):
        return os.path.exists(self._key_path)

    @property
    def passphrase(self):
        return self._password

    @property
    def password(self):
        return self._decrypt()

    @property
    def username(self):
        return self._username

    @property
    def label(self):
        return self._name



import logging
import os
import datetime
import sqlalchemy as sa
import sqlalchemy.orm as orm
import sqlalchemy.ext.declarative as dec
from torrent_ds.error import DataBaseError

DB_FILE_DIR = os.path.expanduser("~/.local/share/torrent_ds")
DB_FILE_PATH = os.path.join(DB_FILE_DIR, "database.db")
SqlAlchemyBase = dec.declarative_base()
__factory = None



def global_init():
    global __factory

    if __factory:
        return

    logger = logging.getLogger("torrent-ds")

    if not os.path.exists(DB_FILE_DIR):
        os.makedirs(DB_FILE_DIR)

    conn_str = 'sqlite:///' + DB_FILE_PATH
    logger.info("Connecting to DB -> {}".format(conn_str))

    engine = sa.create_engine(conn_str, echo=False)
    __factory = orm.sessionmaker(bind=engine)

    SqlAlchemyBase.metadata.create_all(engine)


def create_session():
    global __factory
    return __factory()


class Torrent(SqlAlchemyBase):
    __tablename__ = "torrents"

    tracker_id = sa.Column(sa.Integer, primary_key=True, nullable=False)
    transmission_id = sa.Column(sa.Integer, nullable=False)
    title = sa.Column(sa.String)
    label = sa.Column(sa.String)
    date = sa.Column(sa.DateTime, default=datetime.datetime.now)



import os
import shutil
import logging
import tempfile
from datetime import datetime
from calendar import monthrange
from ncoreparser import Client as NcoreClient
from ncoreparser import (
    SearchParamType,
    NcoreCredentialError,
    NcoreConnectionError,
    NcoreDownloadError,
    NcoreParserError,
    Size
)
from transmissionrpc import Client as TransmissionClient

from torrent_ds.data import create_session, Torrent
from torrent_ds.creds import Credential


download_categories = {
    "movies": [
        SearchParamType.SD_HUN,
        SearchParamType.SD,
        SearchParamType.DVD_HUN,
        SearchParamType.DVD,
        SearchParamType.DVD9_HUN,
        SearchParamType.DVD9,
        SearchParamType.HD_HUN,
        SearchParamType.HD
    ], "series": [
        SearchParamType.SDSER_HUN,
        SearchParamType.SDSER,
        SearchParamType.DVDSER_HUN,
        SearchParamType.DVDSER,
        SearchParamType.HDSER_HUN,
        SearchParamType.HDSER
    ], "musics": [
        SearchParamType.MP3_HUN,
        SearchParamType.MP3,
        SearchParamType.LOSSLESS_HUN,
        SearchParamType.LOSSLESS
    ], "clips": [
        SearchParamType.CLIP,
    ], "games": [
        SearchParamType.GAME_ISO,
        SearchParamType.GAME_RIP,
        SearchParamType.CONSOLE
    ], "books": [
        SearchParamType.EBOOK_HUN,
        SearchParamType.EBOOK
    ], "programs": [
        SearchParamType.ISO,
        SearchParamType.MISC,
        SearchParamType.MOBIL
    ], "xxx": [
        SearchParamType.XXX_IMG,
        SearchParamType.XXX_SD,
        SearchParamType.XXX_DVD,
        SearchParamType.XXX_HD
    ]
}


class DownloadManager:
    def __init__(self, config):
        self._config = config
        self._logger = logging.getLogger("torrent-ds")

    def _get_transmission_client(self):
        params = {}
        address = self._config["transmission"].get("ip_address")
        if address:
            params["address"] = address
        port = self._config["transmission"].get("port")
        if port:
            params["port"] = port
        if self._config["transmission"].get("authenticate") == "True":
            cred = Credential("transmission")
            params["user"] = cred.username
            params["password"] = cred.password

        try:
            client = TransmissionClient(**params)
        except Exception as e:
            self._logger.error("Error while connecting to tranmission-rpc. {}.".format(e))
            return None
        return client

    def _get_tracker_client(self, credential_title):
        cred = Credential(credential_title)
        try:
            client = NcoreClient(timeout=2)
            client.login(cred.username, cred.password)

        except NcoreCredentialError:
            self._logger.error("Bad credential for label: '{}'.".format(cred.label))
            return None
        except NcoreConnectionError:
            self._logger.warning("Connection error with tracker.")
            return None
        except NcoreParserError as e:
            self._logger.warning("Error while parsing web page. {}".format(e))
            return None
        return client

    def _get_download_path(self, torrent, label):
        for path in download_categories:
            for t_type in download_categories[path]:
                if torrent["type"] == t_type:
                    full_path = self._config[label].get(path)
                    return full_path if full_path else None

    def _reached_limit(self, db_session, label):
        # Get number of torrents for label in the target month
        # Returns True if reached the limit
        now = datetime.now()
        last_day = monthrange(now.year, now.month)[1]
        start_date = datetime(year=now.year, month=now.month, day=1)
        end_date = datetime(year=now.year, month=now.month, day=last_day)
        torrents = db_session.query(Torrent).filter(Torrent.date.between(start_date, end_date)) \
                                            .filter(Torrent.label.contains(label)).count()
        limit = self._config[label].get("limit")
        if limit:
            limit = int(limit)
            if torrents >= limit:
                self._logger.info("The download limit is reached. Label: {}, limit: {}/{}".format(label, torrents, limit))
                return True
        return False

    def _add_torrent(self, torrent, tracker_client, tranmission_client, label):
        if tracker_client is None:
            return
        db_session = create_session()

        if db_session.query(Torrent).filter(Torrent.tracker_id==torrent["id"]).count() != 0:
            db_session.close()
            return

        if self._reached_limit(db_session, label):
            db_session.close()
            return

        tmp_dir = tempfile.mkdtemp()
        os.chmod(tmp_dir, 0o777)
        try:
            file_path = tracker_client.download(torrent, tmp_dir)
        except NcoreConnectionError:
            self._logger.warning("Unable to connect to tracker while"
                                 " downloading '{}'.".format(torrent['title']))
            return None
        except NcoreDownloadError as e:
            self._logger.warning(e.args[0])
            return None
        except NcoreParserError as e:
            self._logger.warning("Error while parsing web page. {}".format(e))
            return None

        d_path = self._get_download_path(torrent, label)
        if d_path:
            args = {
                "download_dir": os.path.abspath(d_path)
            }
        else:
            d_path = "default download dir."
            args = {}
        new_torrent = tranmission_client.add_torrent(file_path, **args)
        torrent_db = Torrent()
        torrent_db.tracker_id = torrent["id"]
        torrent_db.transmission_id = new_torrent.id
        torrent_db.title = torrent["title"]
        torrent_db.label = label
        db_session.add(torrent_db)
        db_session.commit()
        self._logger.info("Download torrent: '{}' to '{}'.".format(torrent['title'], d_path))
        shutil.rmtree(tmp_dir)
        db_session.close()

    def clean_db(self):
        client = self._get_transmission_client()
        if client is None:
            return

        try:
            client_ids = [torrent.id for torrent in client.get_torrents()]
        except Exception: # Error while get torrents (timeout)
            self._logger.warning("Unable to clean database (time out)")
            return
        deleted_cnt = 0
        db_session = create_session()
        db_torrents = db_session.query(Torrent).all()
        for item in db_torrents:
            if item.transmission_id not in client_ids:
                db_session.delete(item)
                deleted_cnt += 1
        db_session.commit()
        self._logger.info("Cleaned {} items from db.".format(deleted_cnt))

        db_session.close()

    def download_rss(self):
        transmission_client = self._get_transmission_client()
        if transmission_client is None:
            return
        rss_list = [rss for rss in self._config.sections() if rss.startswith("rss")]
        for rss in rss_list:
            url = self._config[rss]["url"]
            credential = self._config[rss]["credential"]
            self._logger.info("Get torrents from rss: '{}', label: '{}'.".format(url, rss))

            tracker_client = self._get_tracker_client(credential)
            if tracker_client is None:
                return

            try:
                torrents = tracker_client.get_by_rss(url)
            except NcoreConnectionError:
                self._logger.warning("Unable to connect to tracker, "
                                     "while get rss.")
                return
            except NcoreParserError as e:
                self._logger.warning("Error while parsing web page. {}".format(e))
                return

            for torrent in torrents:
                self._add_torrent(torrent, tracker_client, transmission_client, rss)
            tracker_client.logout()

    def download_recommended(self):
        tracker_client = self._get_tracker_client(self._config["recommended"]["credential"])
        if tracker_client is None:
            return
        transmission_client = self._get_transmission_client()
        if transmission_client is None:
            return
        size_cfg = self._config["recommended"].get("max_size")
        self._logger.info("Downloading recommended...")
        categories = self._config["recommended"]["categories"].split(";")
        for category in categories:
            types = download_categories.get(category)
            if types is None:
                self._logger.warning("Unknown category: '{}'.".format(category))
                return
            for type in types:
                try:
                    torrents = tracker_client.get_recommended(type)
                except NcoreConnectionError:
                    self._logger.warning("Unable to connect to tracker,"
                                         " while getting recommended.")
                    continue
                except NcoreParserError as e:
                    self._logger.warning("Error while parsing web page. {}".format(e))
                    continue
                for torrent in torrents:
                    if size_cfg and torrent['size'] > Size(size_cfg):
                        self._logger.info("Skipping torrent '{}', it is too large: '{}'.".format(torrent['title'],
                                                                                                 torrent['size']))
                        continue
                    self._add_torrent(torrent, tracker_client, transmission_client, "recommended")
        tracker_client.logout()

    def start_all(self):
        client = self._get_transmission_client()
        if client is None:
            return
        self._logger.info("Starting all torrents.")
        if len(client.get_torrents()) == 0:
            return
        client.start_all()

    def stop_all(self):
        client = self._get_transmission_client()
        if client is None:
            return
        ids = [torrent.id for torrent in client.get_torrents()]
        self._logger.info("Stopping all torrents.")
        if len(ids) > 0:
            client.stop_torrent(ids)



import os
import logging
from configparser import ConfigParser


CONFIG_PATH_DIR = os.path.expanduser("~/.config/torrent_ds")
CONFIG_PATH = os.path.join(CONFIG_PATH_DIR, "config.ini")
CREDENTIAL_PATH = os.path.join(CONFIG_PATH_DIR, "credentials.ini")
KEY_PATH = os.path.join(CONFIG_PATH_DIR, "key")
CREDENTIALS_SAMPLE = """
[transmission]
user_name = username
raw_password = password
password =

[cred1]
user_name = username
raw_password = password
password =

[cred2]
user_name = username
raw_password = password
password =
"""

CONFIG_SAMPLE = """
[transmission]
authenticate = False
ip_address =
port =
sleep_days =
sleep_time =

[download]
# second
retry_interval = 10

[recommended]
enable = False
credential = cred1
categories = movies;series;musics;games;programs;books;xxx
max_size = 3 GiB
# hour
retry_interval = 5
movies =
series =
musics =
games =
books =
programs =
xxx =

[rss bookmark1]
credential = cred1
limit =
url =
movies =
series =
musics =
clips =
games =
books =
programs =
xxx =

[rss bookmark2]
credential = cred2
limit =
url =
movies =
series =
musics =
clips =
games =
books =
programs =
xxx =
"""


logger = logging.getLogger("torrent-ds")


def check_conf_dir():
    if not os.path.exists(CONFIG_PATH_DIR):
        logger.info(f"Creating directory: '{CONFIG_PATH_DIR}'")
        os.makedirs(CONFIG_PATH_DIR)


def load_config():
    check_conf_dir()
    config = ConfigParser()
    if not config.read(CONFIG_PATH):
        with open(CONFIG_PATH, 'w') as f:
            f.write(CONFIG_SAMPLE)
        config.read(CONFIG_PATH)
    logger.info(f"Read config file: '{CONFIG_PATH}'")
    return CONFIG_PATH, config


def load_credentials():
    check_conf_dir()
    credentials = ConfigParser()
    if not credentials.read(CREDENTIAL_PATH):
        with open(CREDENTIAL_PATH, 'w') as f:
            f.write(CREDENTIALS_SAMPLE)
        credentials.read(CREDENTIAL_PATH)
    return CREDENTIAL_PATH, credentials


def get_key_path():
    check_conf_dir()
    return KEY_PATH


import logging
from logging.handlers import SysLogHandler

def init_logger():
    syslog = SysLogHandler(address="/dev/log")
    syslog.setFormatter(logging.Formatter('%(name)s: %(levelname)s %(message)s'))
    logger = logging.getLogger("torrent-ds")
    logger.addHandler(syslog)
    logger.setLevel(logging.INFO)
    logger.info("Logging was initialized.")



import os
import sys
import logging
import time
import inspect
from datetime import datetime

import torrent_ds.error
from torrent_ds.error import MissingConfigError
from torrent_ds.data import global_init as db_init
from torrent_ds.logger import init_logger
from torrent_ds.download import DownloadManager
from torrent_ds.config import load_config
from torrent_ds.util import (
    check_time,
    check_between_time,
    check_sleep_day
)

def main():
    # Initialize logger
    init_logger()

    # Load configuration
    _, config = load_config()

    logger = logging.getLogger("torrent-ds")
    try:
        db_init()

        if config["recommended"].get("enable") != "True":
            logger.info("Recommended function is disabled. Skip.")

        start_time = datetime.now()
        start_time_recommended = datetime.now()
        # state of torrents in transmission
        started = True
        while True:

            if check_time(start_time, seconds=int(config["download"]["retry_interval"])):
                DownloadManager(config).clean_db()
                DownloadManager(config).download_rss()
                start_time = datetime.now()

            if config["recommended"].get("enable") == "True":
                if check_time(start_time_recommended, hours=int(config["recommended"]["retry_interval"])):
                    DownloadManager(config).download_recommended()
                    start_time_recommended = datetime.now()

            sleep_days = config["transmission"].get("sleep_days")
            sleep_time = config["transmission"].get("sleep_time")
            if sleep_time and sleep_days:
                if (check_between_time(sleep_time.split('-')[0], sleep_time.split('-')[1])
                    and check_sleep_day(sleep_days.split(';'))):
                    if started:
                        DownloadManager(config).stop_all()
                        started = False
                else:
                    if not started:
                        DownloadManager(config).start_all()
                        started = True

            time.sleep(1)

    except KeyboardInterrupt:
        logger.info("Exiting application.")
        sys.exit(0)

    except Exception as e:
        for _, obj in inspect.getmembers(torrent_ds.error):
            if inspect.isclass(obj) and isinstance(e, obj):
                sys.exit(1)
        logger.exception("Unhandled exception: {}".format(e))
        sys.exit(1)


if __name__ == "__main__":
    main()



from datetime import datetime, timedelta


def check_time(start, **kwargs):
    now = datetime.now()
    if now - start >= timedelta(**kwargs):
        return True
    else:
        return False

def check_between_time(before, after):
    before = datetime.strptime(before, "%H:%M:%S").time()
    after = datetime.strptime(after, "%H:%M:%S").time()
    now = datetime.now().time()
    return before < now < after

def check_sleep_day(days_list):
    # isoweekday -> 1:monday 7:sunday
    return str(datetime.now().isoweekday()) in days_list



import os
import sys
import json
import argparse
from torrent_ds.data import (
        global_init,
        create_session,
        Torrent
)

def main():
    parser = argparse.ArgumentParser(description='Process some integers.')
    parser.add_argument('--json', '-j',
                        action="store_true",
                        help="Output format is json.")

    parser.add_argument('--number', '-n',
                        action="store_true",
                        help="Print number of torrents.")

    parser.add_argument('--label', '-l',
                        metavar='LABEL',
                        type=str,
                        help="Filter the labels.")

    parser.add_argument('--title', '-t',
                        metavar='TITLE',
                        type=str,
                        help="Filter the title.")


    args = parser.parse_args()

    global_init()

    session = create_session()

    torrents = session.query(Torrent).order_by(Torrent.date.desc())
    if args.label or args.title:
        if args.label:
            torrents = torrents.filter(Torrent.label.contains(args.label))
        if args.title:
            torrents = torrents.filter(Torrent.title.contains(args.title))
    else:
        torrents = torrents.all()

    session.close()

    if args.number:
        print("Number of torrents: "
            "{}.".format(len(list(torrents))))
        sys.exit(0)

    elif args.json:
        json_data = {}
        for t in torrents:
            if t.label not in json_data:
                json_data[t.label] = []
            json_data[t.label].append({
                "title": t.title,
                "tracker_id": t.tracker_id,
                "client_id": t.transmission_id,
                "date": str(t.date)
            })
        print(json.dumps(json_data, indent=2))

    else:
        row = "|{:^40}|{:^90}|{:^40}|{:^15}|{:^15}|"
        separate = "{}".format('-'*206)

        print(separate)
        print(row.format("Label", "Title", "Date", "Tracker id", "Client id"))
        print(separate)
        for t in torrents:
            print(separate)
            title = t.title if len(t.title) <= 80 else "{}...".format(t.title[:77])
            print(row.format(t.label, title, str(t.date), t.tracker_id,
                            t.transmission_id))
        print(separate)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['torrent_ds', 'torrent_ds_tools']

package_data = \
{'': ['*']}

install_requires = \
['cryptography==3.3.2',
 'ncoreparser',
 'pyopenssl==19.1.0',
 'sqlalchemy==1.3.16',
 'transmissionrpc-ng==0.12.0']

entry_points = \
{'console_scripts': ['torrent-ds = torrent_ds.torrent_ds:main',
                     'torrent-ds-data = torrent_ds_tools.read_data:main']}

setup_kwargs = {
    'name': 'torrent-ds',
    'version': '2.0.4',
    'description': 'Manage downloads using ncoreparser package.',
    'long_description': '# Torrent-ds service\n\n## Leírás\nTorrentszerver applikáció Ncore-hoz. Képes kezelni az rss feed-eket illetve az Ncore ajánlott funkcióját.\nÖszekapcsolható a Transmisison-al, ami le tudja tölteni a torrent tartalmát.\n\nFunkciók:\n* Periódikusan megnyitja a torrenteket az rss feed linkeket használva, és a meghatározott kategóriákat képes külön könyvtárakba letölteni. (Bármennyi rss link megadható)\n* A konfigurációban meghatározott intervallum alatt leállítja az összes torrentet (pl.: napközben munka mellett) (opcionális)\n* Meghatározott időnként letölti a staff által ajánlottnak jelölt torrenteket, kategóriánként beállított könyvtárakba (opcionális)\n\n\n## Telepítés\n\n```\npip install torrent-ds --upgrade --user\n```\n```\necho "[Unit]\nDescription=Torrent-ds service\nAfter=multi-user.target\nConflicts=getty@tty1.service\n[Service]\nUser=${USER}\nType=simple\nEnvironment="LC_ALL=C.UTF-8"\nEnvironment="LANG=C.UTF-8"\nExecStart=${HOME}/.local/bin/torrent-ds\n[Install]\nWantedBy=multi-user.target" | sudo tee /etc/systemd/system/torrent-ds.service\n```\n```\nsudo systemctl daemon-reload\nsudo systemctl enable torrent-ds.service\nsudo systemctl start torrent-ds.service\n```\n\n## Konfiguráció\n\nKét fájl tartalmazza az összes konfigurációt a programhoz:\n* $HOME/.config/torrent_ds/config.ini\n* $HOME/.config/torrent_ds/credentials.ini\n\n### config.ini\nMinden szekció ([]-ben) kötelező mező (kivéve az rss), a többi lehet opcionális vagy kötelező.\n```\n[transmission]\nauthenticate = False  | Kötelező\n                      | A lehetséges értékek: True és False.\n                      | Értelemszerűen ha azonosításra van szükség: True.\n                      | A hozzá tartozó azonosító adatokat a credentials.ini fájl\n                      | [transmission] szekcióban kell definiálni\nip_address =          | Opcionális\n                      | A transmission remote ip_címe\nport =                | Opcionális\n                      | A transmission remote port-ja. Az alapértelmezett: 9091\nsleep_days =          | Opcionális\n                      | A megadott napokon fog érvénybe lépni a sleep_time értéke\n                      | 1:hétfő -> 7:vasárnap, ;-vel elválasztva. Pl.: 1;2;3;4;5\n                      | vagyis hétfő,kedd,szerda,csütörtök,péntek. Ezeken a napokon\n                      | fog végrehajtódni.\nsleep_time =          | Opcionális\n                      | A megadott intervallumban az aktuálisan futó torrenteket\n                      | szünetelteti. A formátum: 00:00:00-00:00:00\n\n[download]\nretry_interval = 10   | Kötelező\n                      | Az rss feed-ek ellenőrzési intervalluma másodperben\n\n[recommended]         | A staff által ajánlottnak jelölt torrentek letöltése\n                      | meghatározottan periódusonként.\nenable = False        | Kötelező\n                      | Lehetséges értékek True és False.\ncredential = cred1    | Kötelező\n                      | Azonosító szekció a credentials.ini fájlban\ncategories =          | Opcionális\n                      | ;-vel elválasztva a kategóriákat. A kategóriák az alábbiak lehetnek:\n                      | movies;series;musics;games;books;programs;xxx\nmax_size = 3 GiB      | Opcionális\n                      | Maximum limit. Az ennél nagyobb méretű torrenteket nem tölti le\n                      | ajánlott módban. Lehetséges dimenziók: KiB, MiB, GiB, TiB.\n                      | A helyes formátum: \'<érték> <dimenzió>\'\nretry_interval = 5    | Kötelező\n                      | Az ajánlott torrentek letöltésének gyakorisága (órában)\nmovies =              | A filmeket az itt megadott mappába tölti le pl: /home/osmc/Downloads/movies\nseries =              | A sorozatokat az itt megadott mappába tölti le pl: /home/osmc/Downloads/series\nmusics =              | A zenéket az itt megadott mappába tölti le pl: /home/osmc/Downloads/musics\ngames =               | A játékokat az itt megadott mappába tölti le pl: /home/osmc/Downloads/games\nbooks =               | A könyveket az itt megadott mappába tölti le pl: /home/osmc/Downloads/books\nprograms =            | A filmeket az itt megadott mappába tölti le pl: /home/osmc/Downloads/programs\nxxx =\n\n[rss bookmark1]       | Az rss-el kezdődő szekció: [rss <szekciónév>] pl: [rss Bela_rss]\ncredential = cred1    | Kötelező\n                      | Azonosító szekció a credentials.ini fájlban\nurl =                 | Kötelező, Rss url -> ncore könyvjelzők\nlimit =               | Letölthető torrentek száma havonta\nmovies =              | A filmeket az itt megadott mappába tölti le pl: /home/osmc/Downloads/movies\nseries =              | A sorozatokat az itt megadott mappába tölti le pl: /home/osmc/Downloads/series\nmusics =              | A zenéket az itt megadott mappába tölti le pl: /home/osmc/Downloads/musics\ngames =               | A játékokat az itt megadott mappába tölti le pl: /home/osmc/Downloads/games\nbooks =               | A könyveket az itt megadott mappába tölti le pl: /home/osmc/Downloads/books\nprograms =            | A filmeket az itt megadott mappába tölti le pl: /home/osmc/Downloads/programs\nxxx =\n\n[rss bookmark2]       | Bármennyi rss szekció használható\ncredential = cred2\nurl =\nmovies =\nseries =\nmusics =\nclips =\ngames =\nbooks =\nprograms =\nxxx =\n```\n\n### credentials.ini\nMinden szekció opcionális és bárhogy elnevezhető. Fontos: A config.ini \'credential\' neveit itt kell definiálni.\nA username értéke legyen a felhasználónév és a raw_password a jelszó. A jelszó automatikusan títkosítva lesz\nés visszakerül a password értékeként, a raw_password törlődik.\n```\n[transmission]      | Azonsító a Transmission-hoz. Ha az authenticate értéke True a config.ini-ben\nuser_name =         | Transmission felhasználónév\nraw_password =      | Transmission jelszó\npassword =          | Titkosított jelszó. Automatikusan íródik ki\n\n[cred1]             | Azonosító mező az Ncore-hoz. Bármilyen nevet kaphat pl.: [Bela]\nuser_name =         | Felhasználónév\nraw_password =      | Jelszó\npassword =          | Titkosított jelszó.\n\n[cred2]\nuser_name =\nraw_password =\npassword =\n```\n## Használat\n### torrent-ds service indítása\n```\nsudo systemctl start torrent-ds\n```\n### torrent-ds service megállítása\n```\nsudo systemctl stop torrent-ds\n```\n### logok megtekintése\n```\njournalctl -fu torrent-ds\n```\n### Bármilyen konfiguráció módosítása után újraindítás szükséges\n```\nsudo systemctl restart torrent-ds\n```\n',
    'author': 'Aron Radics',
    'author_email': 'aron.radics.jozsef@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/radaron/torrent-ds',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
